#!/usr/bin/python
""  # line:6
import argparse  # line:7
import os  # line:8
import sys  # line:9

from qatools import __description__  # line:11
from qatools import __version__  # line:12
from qatools.adb import decryption  # line:13
from qatools.adb import get_adb_path  # line:14
from qatools.adb import get_host_ip  # line:15

adb = get_adb_path()  # line:17


def main():  # line:20
    O0OOOO0OO000O0OOO = argparse.ArgumentParser(description=__description__)  # line:21
    O0OOOO0OO000O0OOO.add_argument(
        "-v", "--version", dest="version", action="store_true", help="show version"
    )  # line:25
    O000O00000OOO0O00 = O0OOOO0OO000O0OOO.add_subparsers(
        help="sub-command help"
    )  # line:26
    O000O00000OOO0O00.add_parser("clear", help="clear app cache data.")  # line:27
    O000O00000OOO0O00.add_parser("info", help="show app setting page.")  # line:27
    O000O00000OOO0O00.add_parser(
        "adb", help="complete adb debugging capability."
    )  # line:28
    O000O00000OOO0O00.add_parser(
        "remote", help="open Android device remote debugging port(5555)."
    )  # line:31
    O000O00000OOO0O00.add_parser(
        "proxy", help=f"enable device global proxy({get_host_ip()}:8888)."
    )  # line:34
    O000O00000OOO0O00.add_parser(
        "unproxy", help=f"disable device global proxy."
    )  # line:35
    if len(sys.argv) == 1:  # line:37
        O0OOOO0OO000O0OOO.print_help()  # line:39
        sys.exit(0)  # line:40
    elif len(sys.argv) == 2:  # line:41
        if sys.argv[1] in ["-v", "--version"]:  # line:43
            print(f"{__version__}")  # line:45
        elif sys.argv[1] == "remote":  # line:47
            ret = os.system(f"{adb} tcpip 5555")  # line:49
            if ret == 0:
                print("已经开启端口5555远程调试，请检查是否开启成功。")
            sys.exit(0)  # line:50
        elif sys.argv[1] == "proxy":  # line:51
            ret = os.system(
                f'{adb} {decryption(b"c2hlbGwgc2V0dGluZ3MgcHV0IGdsb2JhbCBodHRwX3Byb3h5")} {get_host_ip()}:8888'
            )  # line:55
            if ret == 0:
                print(f"已经开启代理，请检查是否开启成功。{get_host_ip()}:8888")
            sys.exit(0)  # line:56
        elif sys.argv[1] == "unproxy":  # line:58
            ret = os.system(
                f'{adb} {decryption(b"c2hlbGwgc2V0dGluZ3MgcHV0IGdsb2JhbCBodHRwX3Byb3h5IDow")}'
            )  # line:62
            if ret == 0:
                print("已经关闭代理，请检查是否关闭成功。")  # line:63
            sys.exit(0)
        elif sys.argv[1] == "adb":  # line:65
            os.system(f"{adb}")  # line:67
            sys.exit(0)

        if sys.argv[1] == "clear":  # line:83
            os.system(f"{adb} shell pm clear {decryption(b'Y29tLnltdDM2MC5hcHAubWFzcw==')}")  # line:84

        elif sys.argv[1] == "info":  # line:83
            os.system(f"{adb} shell am start -a android.settings.APPLICATION_DETAILS_SETTINGS -d package:{decryption(b'Y29tLnltdDM2MC5hcHAubWFzcw==')}")  # line:84

        elif sys.argv[1] in ["-h", "--help"]:  # line:69
            O0OOOO0OO000O0OOO.print_help()  # line:71
        else:  # line:72
            O0OOOO0OO000O0OOO.print_help()  # line:73
        sys.exit(0)  # line:74
    elif sys.argv[1] == "adb":  # line:76
        del sys.argv[0:2]  # line:77
        O0000OOOO00O0000O = " ".join(
            [str(OOO0O0OO0OOO0O00O) for OOO0O0OO0OOO0O00O in sys.argv]
        )  # line:78
        os.system(f"{adb} {O0000OOOO00O0000O}")  # line:79
        sys.exit(0)  # line:80
    elif len(sys.argv) == 3:  # line:82
        if sys.argv[1] == "clear":  # line:83
            os.system(f"{adb} shell pm clear {sys.argv[2]}")  # line:84

        elif sys.argv[1] == "info":  # line:83
            os.system(f"{adb} shell am start -a android.settings.APPLICATION_DETAILS_SETTINGS -d package:{sys.argv[2]}")  # line:84

        elif sys.argv[1] == "proxy":  # line:51
            ret = os.system(
                f'{adb} {decryption(b"c2hlbGwgc2V0dGluZ3MgcHV0IGdsb2JhbCBodHRwX3Byb3h5")} {get_host_ip()}:{sys.argv[2]}'
            )  # line:55
            if ret == 0:
                print(f"已经开启代理，请检查是否开启成功。{get_host_ip()}:{sys.argv[2]}")
            sys.exit(0)
        sys.exit(0)  # line:85
    O0000OOOO00O0000O = O0OOOO0OO000O0OOO.parse_args()  # line:87
    if O0000OOOO00O0000O.version:  # line:89
        print(f"{__version__}")  # line:90
        sys.exit(0)  # line:91



#!/usr/bin/python
""  # line:6
import base64  # line:7
import os  # line:8
import platform  # line:9
import socket  # line:10
import stat  # line:11

import psutil  # line:13

STATICPATH = os.path.dirname(os.path.realpath(__file__))  # line:15
DEFAULT_ADB_PATH = {
    "Windows": os.path.join(STATICPATH, "adb", "windows", "adb.exe"),
    "Darwin": os.path.join(STATICPATH, "adb", "mac", "adb"),
    "Linux": os.path.join(STATICPATH, "adb", "linux", "adb"),
    "Linux-x86_64": os.path.join(STATICPATH, "adb", "linux", "adb"),
    "Linux-armv7l": os.path.join(STATICPATH, "adb", "linux_arm", "adb"),
}  # line:22


def make_file_executable(O000OO000OO0OO0O0):  # line:25
    """"""  # line:30
    if os.path.isfile(O000OO000OO0OO0O0):  # line:31
        OOOOO00O00O0O00O0 = os.lstat(O000OO000OO0OO0O0)[stat.ST_MODE]  # line:32
        OO0OOO0OOOOOOOOO0 = (
            True if OOOOO00O00O0O00O0 & stat.S_IXUSR else False
        )  # line:33
        if not OO0OOO0OOOOOOOOO0:  # line:34
            os.chmod(
                O000OO000OO0OO0O0,
                OOOOO00O00O0O00O0 | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH,
            )  # line:35
        return True  # line:36
    return False  # line:37


def builtin_adb_path():  # line:40
    OOOO00O00000O0OOO = platform.system()  # line:41
    O0OO0OO00O00OO0O0 = platform.machine()  # line:42
    OO0O0O00O00OO00OO = DEFAULT_ADB_PATH.get(
        f"{OOOO00O00000O0OOO}-{O0OO0OO00O00OO0O0}"
    )  # line:43
    if not OO0O0O00O00OO00OO:  # line:44
        OO0O0O00O00OO00OO = DEFAULT_ADB_PATH.get(OOOO00O00000O0OOO)  # line:45
    if not OO0O0O00O00OO00OO:  # line:46
        raise RuntimeError(
            f"No adb executable supports this platform({OOOO00O00000O0OOO}-{O0OO0OO00O00OO0O0})."
        )  # line:49
    if OOOO00O00000O0OOO != "Windows":  # line:51
        make_file_executable(OO0O0O00O00OO00OO)  # line:53
    return OO0O0O00O00OO00OO  # line:54


def get_adb_path():  # line:57
    if platform.system() == "Windows":  # line:58
        OOOOOOOOO0OO0O00O = "adb.exe"  # line:59
    else:  # line:60
        OOOOOOOOO0OO0O00O = "adb"  # line:61
    for O00OO00OOOO000O00 in psutil.process_iter(["name", "exe"]):  # line:64
        if O00OO00OOOO000O00.info["name"] == OOOOOOOOO0OO0O00O:  # line:65
            return O00OO00OOOO000O00.info["exe"]  # line:66
    O00O0OOOOOO00O00O = os.environ.get("ANDROID_HOME")  # line:69
    if O00O0OOOOOO00O00O:  # line:70
        O0O0000O000OO000O = os.path.join(
            O00O0OOOOOO00O00O, "platform-tools", OOOOOOOOO0OO0O00O
        )  # line:71
        if os.path.exists(O0O0000O000OO000O):  # line:72
            return O0O0000O000OO000O  # line:73
    O0O0000O000OO000O = builtin_adb_path()  # line:76
    return O0O0000O000OO000O  # line:77


def get_host_ip():  # line:80
    """"""  # line:84
    O0O0O0O0000OO00O0 = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)  # line:85
    try:  # line:86
        O0O0O0O0000OO00O0.connect(("8.8.8.8", 80))  # line:87
        OOOO0000OO0000OO0 = O0O0O0O0000OO00O0.getsockname()[0]  # line:88
    finally:  # line:89
        O0O0O0O0000OO00O0.close()  # line:90
    return OOOO0000OO0000OO0  # line:92


def encryption(O000O00OOOO0OO00O):  # line:95
    """"""  # line:100
    O00O0OO0O0OOO0000 = O000O00OOOO0OO00O.encode("utf-8")  # line:101
    OOO00O000OOO0OO00 = base64.b64encode(O00O0OO0O0OOO0000)  # line:102
    return OOO00O000OOO0OO00  # line:103


def decryption(O00O0OOO0OO000O00):  # line:106
    """"""  # line:111
    O0O00OO0OOOOOO00O = base64.b64decode(O00O0OOO0OO000O00).decode("utf-8")  # line:112
    return O0O00OO0OOOOOO00O  # line:113



#!/usr/bin/env python
from setuptools import find_packages
from setuptools import setup

from qatools import __version__

with open("README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="qatools",
    version=f"{__version__}",
    keywords=["utx", "adb", "qa", "tools"],
    description="QA is an advanced tool for Android testing!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="Apache License 2.0",
    url="https://openutx.cn/",
    author="lijiawei",
    author_email="jiawei.li2@qq.com",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console :: Curses",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    entry_points="""
    [console_scripts]
    qa = qatools.cli:main
    """,
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=[
        "psutil",
    ],
)
